@@ -133,6 +133,9 @@ void Event::MainLoop()
     // flushed until select is returned.
     XFlush(display);
 
+    if (XPending(display) > 0)
+      continue;
+
 #if defined(__hpux) && !defined(_XPG4_EXTENDED)
     if (select(fdMax + 1, (int *)&fds, 0, 0, timep) == 0) {    // timeout
 #else
@@ -698,7 +701,6 @@ void Event::MapNotifyProc(const XMapEvent& ev)
 void Event::UnmapNotifyProc(const XUnmapEvent& ev)
 {
   Qvwm* qvWm;
-  Bool yield = False;
 
   if (XFindContext(display, ev.window, Qvwm::context, (caddr_t*)&qvWm)
       == XCSUCCESS) {
