@@ -319,7 +319,7 @@ void AnalizeOptions(int argc, char** argv)
 	  restart = True;
 #ifdef USE_XSMP
 	else if (strcmp(&argv[i][1], "id") == 0 ||
-		 strcmp(&argv[i][1], "clientID") == 0)
+		 strcmp(&argv[i][1], "clientId") == 0)
 	  previousId = argv[++i];
 #endif
 	else if (strcmp(&argv[i][1], "s") == 0 ||
@@ -433,7 +433,6 @@ void InitQvwm()
 
   rootQvwm = new Qvwm(root);
 
-  Rect rect(4, 3, 10, 10);
   ctrlMenu = new Menu(CtrlMenuItem, fsCtrlMenu, NULL, NULL);
 
   Icon::ctrlMenu = new IconMenu(IconMenuItem, fsCtrlMenu, NULL, NULL);
@@ -683,10 +682,6 @@ void CreateInternAtom()
  */
 void CreateLogoMarkPixmap()
 {
-  XpmAttributes attr;
-  Pixmap mask;
-  XGCValues gcv;
-
   if (DefaultIcon == NULL)
     imgLogo = new PixmapImage(logo16);
   else {
