@@ -61,11 +61,11 @@ QvImage 	*Menu::imgMenuBack, *Menu::imgActiveMenuBack;
 Menu::Menu(MenuElem* mItem, XFontSet& menufs, Menu* par, Qvwm* qvwm,
 	   int lMargin, int nMargin, int hMargin,
 	   QvImage* imgDefFolder, QvImage* imgDefIcon)
-: leftMargin(lMargin), nameMargin(nMargin), hiMargin(hMargin),
-  parent(par), fs(menufs), qvWm(qvwm)
+: parent(par), leftMargin(lMargin), nameMargin(nMargin), hiMargin(hMargin),
+  fs(menufs), qvWm(qvwm)
 {
   int maxWidth = 0, width;
-  Dim maxImgSize(0, 0), size;
+  Dim maxImgSize(0, 0);
   int i, sep = 0;
   XSetWindowAttributes attributes;
   unsigned long valueMask;
@@ -936,6 +936,9 @@ Bool Menu::IsChecked(FuncNumber fn)
     if (TaskbarAutoHide)
       return True;
     break;
+
+  default:
+    break;
   }
 
   return False;
@@ -967,6 +970,9 @@ Bool Menu::IsSelected(FuncNumber fn)
       if (taskBar->GetPos() == Taskbar::RIGHT)
 	return True;
     break;
+
+  default:
+    break;
   }
 
   return False;
