@@ -734,7 +734,9 @@ void CreateSCKeyFunc(char* key, unsigned int mod, char* func)
  */
 void CreateIndicator(char* comp, char* exec)
 {
-  new Indicator(exec, comp);
+  Indicator *ind;
+
+  ind = new Indicator(exec, comp);
 }
 
 void CreateAccessory(char* filename, char* pos, char* mode)
