@@ -347,14 +347,14 @@ Qvwm::~Qvwm()
 
     if (FrameImage) {
       for (i = 0; i < 4; i++) {
-	QvImage::Destroy(imgSide[4]);
-	QvImage::Destroy(imgCorner[4]);
+	QvImage::Destroy(imgSide[i]);
+	QvImage::Destroy(imgCorner[i]);
       }
     }
     if (FrameActiveImage) {
       for (i = 0; i < 4; i++) {
-	QvImage::Destroy(imgActiveSide[4]);
-	QvImage::Destroy(imgActiveCorner[4]);
+	QvImage::Destroy(imgActiveSide[i]);
+	QvImage::Destroy(imgActiveCorner[i]);
       }
     }
 
