@@ -29,7 +29,7 @@ class RadioButton;
  * RadioSet class
  */
 class RadioSet {
-friend RadioButton;
+  friend class RadioButton;
 private:
   RadioButton** rb;               // RadioButton belonging to this set
   int num;                        // # of RadioButton
