@@ -28,14 +28,14 @@
  */
 class StartButton : public TaskbarButton {
 public:
-  unsigned int buttonWidth;
+  int buttonWidth;
 
 private:
   void FillBackground();
   void DrawName();
 
 public:
-  StartButton(Qvwm* qvWm, unsigned int some_width);
+  StartButton(Qvwm* qvWm, int some_width);
   ~StartButton() {}
   
   void DrawButton();
