@@ -161,7 +161,6 @@ Taskbar::Taskbar(Qvwm* qvWm, int width, unsigned int rows)
     }
   }
 
-  Rect rect(0, 0, 0, 0);
   ctrlMenu = new Menu(TaskbarMenuItem, fsCtrlMenu, NULL, qvWm);
 
   toolTip = new Tooltip();
@@ -1035,6 +1034,9 @@ Rect Taskbar::GetScreenRectOnShowing() const
   case RIGHT:
     return Rect(0, 0, rcRoot.width - rc[RIGHT].width, rcRoot.height);
   }
+
+  ASSERT(False);
+  return Rect(0, 0, 0, 0);
 }
 
 /*
@@ -1057,6 +1059,9 @@ Rect Taskbar::GetScreenRectOnHiding() const
   case RIGHT:
     return Rect(0, 0, rcRoot.width - 2, rcRoot.height);
   }
+
+  ASSERT(False);
+  return Rect(0, 0, 0, 0);
 }
 
 void Taskbar::ShowTaskbar()
@@ -1168,7 +1173,7 @@ void Taskbar::RedrawAllTaskbarButtons()
 {
   List<Qvwm>::Iterator i(&desktop.GetQvwmList());
   Qvwm* tmpQvwm;
-  unsigned int buttonWidth;
+  int buttonWidth;
   int row, col;
   int buttonNum = 0, count = 0;
   StartButton *sButton = (StartButton *)rootQvwm->tButton;
@@ -1264,6 +1269,10 @@ void Taskbar::RedrawAllTaskbarButtons()
     if (buttonWidth == 0)
       buttonWidth = 1;
     break;
+
+  default:
+    col = row = buttonWidth = 0;  // XXX for warning
+    ASSERT(False);
   }
 
   /*
@@ -1292,6 +1301,10 @@ void Taskbar::RedrawAllTaskbarButtons()
       y = TaskbarButton::rcTButton.y + TaskbarButton::BUTTON_HEIGHT + 12
 	+ (TaskbarButton::rcTButton.height + BETWEEN_SPACE) * (count / col);
       break;
+
+    default:
+      x = y = 0;  // XXX for warning
+      ASSERT(False);
     }
     count++;
     
