@@ -493,7 +493,7 @@ pid_t ExecCommand(char* exec)
 #else
   if ((pid = vfork()) == 0) {
     if (execl(SHELL, SHELL, "-c", cmd, NULL) == -1) {
-      QvwmError("Can't execute '%s'", exec);
+      QvwmError("Can't execute '%s'", &cmd[5]);
       _exit(1);
     }
   }
@@ -732,6 +732,8 @@ void PlaySound(char* file, Bool sync)
       sprintf(paths, "%s:%s", SoundPath, SNDDIR);
       char* pathname = strtok(paths, ":");
 
+      ret = AUDIO_NOFILE;
+
       while (pathname) {
 	char* realpath = ExtractPathName(pathname);
 	int len = strlen(realpath) + 1 + filelen;
