@@ -21,7 +21,7 @@
 #ifndef _VER_H_
 #define _VER_H_
 
-const char* Version = "1.1.7";
-const char* Codename = "Oho";
+const char* Version = "1.1.8";
+const char* Codename = "Takezono";
 
 #endif // _VER_H_
